# RuleResultEnum


## Enum

* `PASS` (value: `'Pass'`)

* `FAIL` (value: `'Fail'`)

* `SKIPPED` (value: `'Skipped'`)

* `UNAVAILABLE` (value: `'Unavailable'`)

* `PARTIALLY_UNAVAILABLE` (value: `'Partially Unavailable'`)

* `MODEL_NOT_AVAILABLE` (value: `'Model Not Available'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


